@@ -93,7 +93,8 @@ type pageMap struct {
 	// Used for simple page lookups by name, e.g. "mypage.md" or "mypage".
 	pageReverseIndex *contentTreeReverseIndex
 
-	cachePages             *dynacache.Partition[string, page.Pages]
+	cachePages1            *dynacache.Partition[string, page.Pages]
+	cachePages2            *dynacache.Partition[string, page.Pages]
 	cacheResources         *dynacache.Partition[string, resource.Resources]
 	cacheContentRendered   *dynacache.Partition[string, *resources.StaleValue[contentSummary]]
 	cacheContentPlain      *dynacache.Partition[string, *resources.StaleValue[contentPlainPlainWords]]
@@ -324,15 +325,19 @@ func (m *pageMap) forEeachPageIncludingBundledPages(include predicate.P[*pageSta
 }
 
 func (m *pageMap) getOrCreatePagesFromCache(
+	cache *dynacache.Partition[string, page.Pages],
 	key string, create func(string) (page.Pages, error),
 ) (page.Pages, error) {
-	return m.cachePages.GetOrCreate(key, create)
+	if cache == nil {
+		cache = m.cachePages1
+	}
+	return cache.GetOrCreate(key, create)
 }
 
 func (m *pageMap) getPagesInSection(q pageMapQueryPagesInSection) page.Pages {
 	cacheKey := q.Key()
 
-	pages, err := m.getOrCreatePagesFromCache(cacheKey, func(string) (page.Pages, error) {
+	pages, err := m.getOrCreatePagesFromCache(nil, cacheKey, func(string) (page.Pages, error) {
 		prefix := paths.AddTrailingSlash(q.Path)
 
 		var (
@@ -348,31 +353,28 @@ func (m *pageMap) getPagesInSection(q pageMapQueryPagesInSection) page.Pages {
 		w := &doctree.NodeShiftTreeWalker[contentNodeI]{
 			Tree:   m.treePages,
 			Prefix: prefix,
-			Handle: func(key string, n contentNodeI, match doctree.DimensionFlag) (bool, error) {
-				if q.Recursive {
-					if p, ok := n.(*pageState); ok && include(p) {
-						pas = append(pas, p)
-					}
-					return false, nil
-				}
-
-				// We store both leafs and branches in the same tree, so for non-recursive walks,
-				// we need to walk until the end, but can skip
-				// any not belonging to child branches.
-				if otherBranch != "" && strings.HasPrefix(key, otherBranch) {
-					return false, nil
-				}
+		}
 
+		w.Handle = func(key string, n contentNodeI, match doctree.DimensionFlag) (bool, error) {
+			if q.Recursive {
 				if p, ok := n.(*pageState); ok && include(p) {
 					pas = append(pas, p)
 				}
-
-				if n.isContentNodeBranch() {
-					otherBranch = key + "/"
-				}
-
 				return false, nil
-			},
+			}
+
+			if p, ok := n.(*pageState); ok && include(p) {
+				pas = append(pas, p)
+			}
+
+			if n.isContentNodeBranch() {
+				currentBranch := key + "/"
+				if otherBranch == "" || otherBranch != currentBranch {
+					w.SkipPrefix(currentBranch)
+				}
+				otherBranch = currentBranch
+			}
+			return false, nil
 		}
 
 		err := w.Walk(context.Background())
@@ -400,7 +402,7 @@ func (m *pageMap) getPagesInSection(q pageMapQueryPagesInSection) page.Pages {
 func (m *pageMap) getPagesWithTerm(q pageMapQueryPagesBelowPath) page.Pages {
 	key := q.Key()
 
-	v, err := m.cachePages.GetOrCreate(key, func(string) (page.Pages, error) {
+	v, err := m.cachePages1.GetOrCreate(key, func(string) (page.Pages, error) {
 		var pas page.Pages
 		include := q.Include
 		if include == nil {
@@ -437,7 +439,7 @@ func (m *pageMap) getPagesWithTerm(q pageMapQueryPagesBelowPath) page.Pages {
 func (m *pageMap) getTermsForPageInTaxonomy(path, taxonomy string) page.Pages {
 	prefix := paths.AddLeadingSlash(taxonomy)
 
-	v, err := m.cachePages.GetOrCreate(prefix+path, func(string) (page.Pages, error) {
+	v, err := m.cachePages1.GetOrCreate(prefix+path, func(string) (page.Pages, error) {
 		var pas page.Pages
 
 		err := m.treeTaxonomyEntries.WalkPrefix(
@@ -488,7 +490,7 @@ func (m *pageMap) forEachResourceInPage(
 	rw.Handle = func(resourceKey string, n contentNodeI, match doctree.DimensionFlag) (bool, error) {
 		if isBranch {
 			ownerKey, _ := m.treePages.LongestPrefixAll(resourceKey)
-			if ownerKey != keyPage {
+			if ownerKey != keyPage && path.Dir(ownerKey) != path.Dir(resourceKey) {
 				// Stop walking downwards, someone else owns this resource.
 				rw.SkipPrefix(ownerKey + "/")
 				return false, nil
@@ -542,7 +544,7 @@ func (m *pageMap) getOrCreateResourcesForPage(ps *pageState) resource.Resources
 				for _, r := range res2 {
 					var found bool
 					for _, r2 := range res {
-						if r2.Name() == r.Name() {
+						if r2.(resource.NameNormalizedProvider).NameNormalized() == r.(resource.NameNormalizedProvider).NameNormalized() {
 							found = true
 							break
 						}
@@ -688,13 +690,13 @@ func (s *contentNodeShifter) Delete(n contentNodeI, dimension doctree.Dimension)
 		}
 		return wasDeleted, isEmpty
 	case *resourceSource:
-		if lidx > 0 {
+		if lidx != v.LangIndex() {
 			return false, false
 		}
 		resource.MarkStale(v)
 		return true, true
 	case *pageState:
-		if lidx > 0 {
+		if lidx != v.s.languagei {
 			return false, false
 		}
 		resource.MarkStale(v)
@@ -864,7 +866,8 @@ func newPageMap(i int, s *Site, mcache *dynacache.Cache, pageTrees *pageTrees) *
 
 	m = &pageMap{
 		pageTrees:              pageTrees.Shape(0, i),
-		cachePages:             dynacache.GetOrCreatePartition[string, page.Pages](mcache, fmt.Sprintf("/pags/%d", i), dynacache.OptionsPartition{Weight: 10, ClearWhen: dynacache.ClearOnRebuild}),
+		cachePages1:            dynacache.GetOrCreatePartition[string, page.Pages](mcache, fmt.Sprintf("/pag1/%d", i), dynacache.OptionsPartition{Weight: 10, ClearWhen: dynacache.ClearOnRebuild}),
+		cachePages2:            dynacache.GetOrCreatePartition[string, page.Pages](mcache, fmt.Sprintf("/pag2/%d", i), dynacache.OptionsPartition{Weight: 10, ClearWhen: dynacache.ClearOnRebuild}),
 		cacheResources:         dynacache.GetOrCreatePartition[string, resource.Resources](mcache, fmt.Sprintf("/ress/%d", i), dynacache.OptionsPartition{Weight: 60, ClearWhen: dynacache.ClearOnRebuild}),
 		cacheContentRendered:   dynacache.GetOrCreatePartition[string, *resources.StaleValue[contentSummary]](mcache, fmt.Sprintf("/cont/ren/%d", i), dynacache.OptionsPartition{Weight: 70, ClearWhen: dynacache.ClearOnChange}),
 		cacheContentPlain:      dynacache.GetOrCreatePartition[string, *resources.StaleValue[contentPlainPlainWords]](mcache, fmt.Sprintf("/cont/pla/%d", i), dynacache.OptionsPartition{Weight: 70, ClearWhen: dynacache.ClearOnChange}),
@@ -1503,13 +1506,6 @@ func (sa *sitePagesAssembler) assembleTermsAndTranslations() error {
 				return false, nil
 			}
 
-			// This is a little out of place, but is conveniently put here.
-			// Check if translationKey is set by user.
-			// This is to support the manual way of setting the translationKey in front matter.
-			if ps.m.pageConfig.TranslationKey != "" {
-				sa.s.h.translationKeyPages.Append(ps.m.pageConfig.TranslationKey, ps)
-			}
-
 			if sa.pageMap.cfg.taxonomyTermDisabled {
 				return false, nil
 			}
@@ -1552,8 +1548,10 @@ func (sa *sitePagesAssembler) assembleTermsAndTranslations() error {
 						}
 						pages.InsertIntoValuesDimension(pi.Base(), n)
 						term = pages.Get(pi.Base())
-					} else if term.(*pageState).m.term != v {
-						term.(*pageState).m.term = v
+					} else {
+						m := term.(*pageState).m
+						m.term = v
+						m.singular = viewName.singular
 					}
 
 					if s == "" {
@@ -1588,6 +1586,13 @@ func (sa *sitePagesAssembler) assembleResources() error {
 		Handle: func(s string, n contentNodeI, match doctree.DimensionFlag) (bool, error) {
 			ps := n.(*pageState)
 
+			// This is a little out of place, but is conveniently put here.
+			// Check if translationKey is set by user.
+			// This is to support the manual way of setting the translationKey in front matter.
+			if ps.m.pageConfig.TranslationKey != "" {
+				sa.s.h.translationKeyPages.Append(ps.m.pageConfig.TranslationKey, ps)
+			}
+
 			// Prepare resources for this page.
 			ps.shiftToOutputFormat(true, 0)
 			targetPaths := ps.targetPaths()
@@ -1633,7 +1638,7 @@ func (sa *sitePagesAssembler) assembleResources() error {
 						TargetBasePaths:      targetBasePaths,
 						BasePathRelPermalink: targetPaths.SubResourceBaseLink,
 						BasePathTargetPath:   baseTarget,
-						Name:                 relPath,
+						NameNormalized:       relPath,
 						NameOriginal:         relPathOriginal,
 						LazyPublish:          !ps.m.pageConfig.Build.PublishResources,
 					}
@@ -1679,6 +1684,11 @@ func (sa *sitePagesAssembler) assemblePagesStep2() error {
 	if err := sa.applyAggregatesToTaxonomiesAndTerms(); err != nil {
 		return err
 	}
+
+	return nil
+}
+
+func (sa *sitePagesAssembler) assemblePagesStepFinal() error {
 	if err := sa.assembleResources(); err != nil {
 		return err
 	}
@@ -1715,6 +1725,7 @@ func (sa *sitePagesAssembler) removeShouldNotBuild() error {
 	if len(keys) == 0 {
 		return nil
 	}
+
 	sa.pageMap.DeletePageAndResourcesBelow(keys...)
 
 	return nil
@@ -1764,7 +1775,7 @@ func (sa *sitePagesAssembler) addStandalonePages() error {
 
 	if s.conf.EnableRobotsTXT {
 		if m.i == 0 || s.Conf.IsMultihost() {
-			addStandalone("/robots", kinds.KindRobotsTXT, output.RobotsTxtFormat)
+			addStandalone("/_robots", kinds.KindRobotsTXT, output.RobotsTxtFormat)
 		}
 	}
 
@@ -1777,11 +1788,11 @@ func (sa *sitePagesAssembler) addStandalonePages() error {
 	}
 
 	if sitemapEnabled {
-		addStandalone("/sitemap", kinds.KindSitemap, output.SitemapFormat)
-		skipSitemapIndex := s.Conf.IsMultihost() || !(s.Conf.DefaultContentLanguageInSubdir() || s.Conf.IsMultiLingual())
+		addStandalone("/_sitemap", kinds.KindSitemap, output.SitemapFormat)
+		skipSitemapIndex := s.Conf.IsMultihost() || !(s.Conf.DefaultContentLanguageInSubdir() || s.Conf.IsMultilingual())
 
 		if !skipSitemapIndex {
-			addStandalone("/sitemapindex", kinds.KindSitemapIndex, output.SitemapIndexFormat)
+			addStandalone("/_sitemapindex", kinds.KindSitemapIndex, output.SitemapIndexFormat)
 		}
 	}
 
@@ -1814,6 +1825,14 @@ func (sa *sitePagesAssembler) addMissingRootSections() error {
 				return false, nil
 			}
 
+			switch ps.Kind() {
+			case kinds.KindPage, kinds.KindSection:
+				// OK
+			default:
+				// Skip taxonomy nodes etc.
+				return false, nil
+			}
+
 			p := ps.m.pathInfo
 			section := p.Section()
 			if section == "" || seen[section] {
